#!/bin/bash
# Script to build QlandkarteGT with QT5 under Ubuntu 20.04 (tested with LinuxMint 20 and xUbuntu 20.04.1)
# By The_Raven
# v1.1
# Todo: Enable Multi-Threading in cmake

# Check if we are root
if [[ $EUID = "0" ]]; then
  echo -e "\a\033[1;37;33mLet's go...\033[0m"
else
  echo -e "\a\033[1;37;31mError:\033[0m Please start this script with "sudo""
  exit 1
fi

# Check if folder allready exist
if [ -d Build-QlandkarteGT ]
    then
    echo -e "\a\033[1;37;31mError:\033[0m Folder already exists, please delete it first!"
    exit 1
fi

echo -e "\a\033[1;37;33mCheck how many CPU-Threads we have...\033[0m"
CPU=`grep "processor" /proc/cpuinfo | sort -u | wc -l`
echo -e "\a\033[1;37;33mFound \a\033[1;37;36m$CPU\033[0m \a\033[1;37;33mCPU-Threads\033[0m"

echo -e "\a\033[1;37;33mCreate build directory...\033[0m"
mkdir Build-QlandkarteGT
cd Build-QlandkarteGT

echo -e "\a\033[1;37;33mInstalling dependencies...\033[0m"
apt update
apt install -y wget git cmake g++ qt5-default libgdal-dev qtdeclarative5-dev qtscript5-dev qtmultimedia5-dev libqt5webkit5-dev libqt5serialport5-dev qttools5-dev

echo -e "\a\033[1;37;33mDownload QlandkarteGT...\033[0m"
wget http://downloads.sourceforge.net/qlandkartegt/qlandkartegt-1.8.1.tar.gz

echo -e "\a\033[1;37;33mUnpack QlandkarteGT...\033[0m"
tar xzf qlandkartegt-1.8.1.tar.gz

echo -e "\a\033[1;37;33mDownload QT5 patches...\033[0m"
git clone https://aur.archlinux.org/qlandkartegt.git

echo -e "\a\033[1;37;33mPatching for QT5...\033[0m"
cd qlandkartegt-1.8.1
patch -Np1 -i ../qlandkartegt/fix-qt5-build.patch
patch -Np1 -i ../qlandkartegt/fix-ver_str.patch
patch -Np1 -i ../qlandkartegt/fix-qtgui-include.patch
patch -Np1 -i ../qlandkartegt/fix-gps_read.patch
patch -Np1 -i ../qlandkartegt/fix-proj_api.patch
patch -Np1 -i ../qlandkartegt/fix-incomplete-type.patch
patch -Np1 -i ../qlandkartegt/fix-timespec.patch
patch -Np1 -i ../qlandkartegt/improve-gpx-creator.patch
patch -Np1 -i ../qlandkartegt/improve-gpx-name.patch
cd ..

echo -e "\a\033[1;37;33mCompiling...\033[0m"
mkdir build
cd build
cmake ../qlandkartegt-1.8.1/ -DCMAKE_INSTALL_PREFIX=/usr -DCMAKE_BUILD_TYPE=Release -DQK_QT5_PORT=ON
make -j $CPU

echo -e "\a\033[1;37;33mInstall QlandkarteGT?\033[0m \a\033[1;37;36my/n\033[0m"
read INSTALL
case $INSTALL in
  y*|Y*) echo -e "\a\033[1;37;33mInstall QlandkarteGT...\033[0m";make install ;;
  n*|N*) echo -e "\a\033[1;37;33mQlandkarteGT not installed!\033[0m" ;;
esac

echo -e "\a\033[1;37;33mCleanUP (delete the Build- and Download folders)?\033[0m \a\033[1;37;36my/n\033[0m"
read INSTALL
case $INSTALL in
  y*|Y*) echo -e "\a\033[1;37;33mCleanUP...\033[0m";cd ..;cd ..;rm -R Build-QlandkarteGT ;;
  n*|N*) echo -e "\a\033[1;37;33mExiting...\033[0m" ;;
  *) exit ;;
esac
